'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var InputBoxDoneTyping = function InputBoxDoneTyping(props) {
  var typingTimer = void 0;
  var before = props.inputDefaultValue;

  var handleOnChange = function handleOnChange(e) {
    if (props.inputOnChange) {
      var value = e.target.value;
      props.inputOnChange(value);
    }
  };

  var handleOnKeyUp = function handleOnKeyUp(e) {
    var value = e.target.value;
    clearTimeout(typingTimer);
    typingTimer = setTimeout(function () {
      doneTyping(value);
    }, props.doneTypingInterval);
  };

  var handleOnKeyDown = function handleOnKeyDown() {
    clearTimeout(typingTimer);
  };

  var doneTyping = function doneTyping(value) {
    if (value.toLowerCase() !== before.toLowerCase()) {
      before = value;
      props.inputDoneTyping(value);
    }
  };

  return _react2.default.createElement('input', {
    type: 'text',
    id: props.inputId,
    autoComplete: props.inputAutoComplete,
    className: props.inputClassName,
    placeholder: props.inputPlaceholder,
    defaultValue: props.inputDefaultValue,
    onChange: handleOnChange,
    onKeyUp: handleOnKeyUp,
    onKeyDown: handleOnKeyDown
  });
};

InputBoxDoneTyping.defaultProps = {
  inputId: '',
  inputClassName: '',
  inputAutoComplete: 'on',
  inputPlaceholder: '',
  inputDefaultValue: '',
  doneTypingInterval: 500
};

InputBoxDoneTyping.propTypes = {
  inputId: _react.PropTypes.string,
  inputAutoComplete: _react.PropTypes.oneOf(['on', 'off']),
  inputClassName: _react.PropTypes.string,
  inputPlaceholder: _react.PropTypes.string,
  inputOnChange: _react.PropTypes.func,
  inputDefaultValue: _react.PropTypes.string,
  doneTypingInterval: _react.PropTypes.number,
  inputDoneTyping: _react.PropTypes.func.isRequired
};

exports.default = InputBoxDoneTyping;
